Skip to contents

Tipo especial de B textural com mudanca textural abrupta + permeabilidade lenta + cores neutras/escurecidas + cromas baixos.

Usage

B_planico(pedon)

Arguments

pedon

A PedonRecord.

Value

A DiagnosticResult recording whether the diagnostic is present, the qualifying layers, and the supporting evidence.