Calcaric material (WRB 2022 Ch 3.3.3): \>= 2% CaCO3 throughout the fine earth, primary carbonates from the parent material.
Source:R/diagnostics-materials-wrb-v033.R
calcaric_material.RdCalcaric material (WRB 2022 Ch 3.3.3): \>= 2% CaCO3 throughout the fine earth, primary carbonates from the parent material.
Arguments
- pedon
A
PedonRecord.- min_caco3_pct
Numeric threshold or option (see Details).