Skip to contents

Given a parsed tests block from a YAML key entry, evaluates the appropriate combinator and returns a list with passed, evidence, missing, and (optionally) notes.

Usage

evaluate_rsg_tests(pedon, tests)

Arguments

pedon

A PedonRecord.

tests

A tests block from the YAML.

Value

A list summarising the test outcome.