Haplic qualifier (ha): no other principal qualifier of the RSG applies. Always passes; the qualifier resolution machinery uses it as the default when no other qualifier matched.
Source:R/qualifiers-wrb2022.R
qual_haplic.RdHaplic qualifier (ha): no other principal qualifier of the RSG applies. Always passes; the qualifier resolution machinery uses it as the default when no other qualifier matched.
Arguments
- pedon
A
PedonRecord.