Resolves name to an absolute file path under the package's
inst/schemas/ directory (which becomes schemas/ in
the installed package). The .json extension is added if
missing.
Resolves name to an absolute file path under the package's
inst/schemas/ directory (which becomes schemas/ in
the installed package). The .json extension is added if
missing.