Test the andic Al/Fe oxalate criterion: (al_ox + 0.5*fe_ox) >= 2.0%
Source:R/utils-diagnostic-tests.R
test_andic_alfe.RdDistinct from spodic (which uses 0.5%); the andic threshold is four times higher per WRB 2022 Chapter 3.

R/utils-diagnostic-tests.R
test_andic_alfe.RdDistinct from spodic (which uses 0.5%); the andic threshold is four times higher per WRB 2022 Chapter 3.