Excludes horizons that are simultaneously massive AND very hard when
dry. v0.1 implementation reads structure_grade and
consistence_moist as text and looks for the keyword pair.
Excludes horizons that are simultaneously massive AND very hard when
dry. v0.1 implementation reads structure_grade and
consistence_moist as text and looks for the keyword pair.