Coerce a horizons-like data.frame to the canonical schema
Source:R/utils.R
ensure_horizon_schema.RdAdds any missing canonical columns as NAs of the right type and reorders canonical columns first. Extra user-supplied columns are preserved at the end. Coerces character values to numeric where the schema requires it.