Given a parsed tests block from a YAML key entry, evaluates
the appropriate combinator and returns a list with passed,
evidence, missing, and (optionally) notes.
Arguments
- pedon
A
PedonRecord.- tests
A
testsblock from the YAML.
Given a parsed tests block from a YAML key entry, evaluates
the appropriate combinator and returns a list with passed,
evidence, missing, and (optionally) notes.
A PedonRecord.
A tests block from the YAML.