Test for an abrupt textural change between adjacent horizons
Source:R/utils-diagnostic-tests.R
test_abrupt_textural_change.RdWRB 2022 planic criterion: clay content of the underlying horizon is
at least double that of the overlying horizon, with the transition
occurring within 7.5 cm vertical distance. v0.3 implements the
clay-doubling test plus an optional boundary_distinctness
check (must be "abrupt" or "very abrupt" on the upper
horizon).